translate.storage.xliff

Package translate :: Package storage :: Module xliff |
[hide private]
[frames] | no frames]

# Module xliff

source code

Module for handling XLIFF files for translation.

The official recommendation is to use the extention .xlf for XLIFF files.

Classes | [hide private]
| xliffunit A single term in the xliff file.
| xlifffile Class representing a XLIFF file store.

Variables | [hide private]
| ID_SEPARATOR = `u"\04"`
| ID_SEPARATOR_SAFE = `u"__%04__"`

Imports: etree, multistring, base, lisa, getXMLspace, xml_to_strelem, strelem_to_xml